import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

import java.util.Random;
import java.util.List;
import java.util.ArrayList;

/**
 * Mole is the animal.
 * 
 * @author Shondel Archer   
 * @version 1.0
 */
public class Actors extends Actor
{

    protected static final int EAST = 0;
    protected static final int WEST = 1;
    protected static final int NORTH = 2;
    protected static final int SOUTH = 3;

    protected int direction;
    protected int molesHit;

    public Actors()
    {
        setDirection(EAST);
        molesHit = 0;
    }

    /**
     * Act - do whatever the WhackAMole wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    
    public void act()
    {

        if(canMove()) 
        {
            move();
        }
        else 
        {
            turnLeft();
        }
    }

    
    /**
     * Move one cell forward in the current direction.
     */
    public void move()
    {
        if (!canMove()) 
        {
            return;
        }
        switch(direction) 
        {
            case SOUTH :
                setLocation(getX(), getY() + 1);
                break;
            case EAST :
                setLocation(getX() + 1, getY());
                break;
            case NORTH :
                setLocation(getX(), getY() - 1);
                break;
            case WEST :
                setLocation(getX() - 1, getY());
                break;
        }
    }

    /**
     * Test if we can move forward. Return true if we can, false otherwise.
     */
    public boolean canMove()
    {
        World myWorld = getWorld();
        int x = getX();
        int y = getY();
        
        switch(direction) 
        {
            case SOUTH :
                y++;
                break;
            case EAST :
                x++;
                break;
            case NORTH :
                y--;
                break;
            case WEST :
                x--;
                break;
        }
        // test for outside border
        if (x >= myWorld.getWidth() || y >= myWorld.getHeight()) 
        {
            return false;
        }
        else if (x < 0 || y < 0) 
        {
            return false;
        }
        return true;
    }

    /**
     * Turns towards the left.
     */
    public void turnLeft()
    {
        switch(direction) 
        {
            case SOUTH :
                setDirection(EAST);
                break;
            case EAST :
                setDirection(NORTH);
                break;
            case NORTH :
                setDirection(WEST);
                break;
            case WEST :
                setDirection(SOUTH);
                break;
        }
    }

    /**
     * Sets the direction we're facing.
     */
    public void setDirection(int direction)
    {
        this.direction = direction;
        switch(direction) 
        {
            case SOUTH :
                setRotation(0);
                break;
            case EAST :
                setRotation(0);
                break;
            case NORTH :
                setRotation(0);
                break;
            case WEST :
                setRotation(0);
                break;
            default :
                break;
        }
    }
    
    
    /**
     * Get the MoleWorld object itself.
     */
    protected final MoleWorld getMoleWorld() 
    {
        return (MoleWorld)getWorld();
    }
}
