import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
import java.util.List;
import java.util.ArrayList;
import java.awt.Color;
import java.awt.Font;
import java.util.Calendar;

/**
 * The Hammer is what is used to hit the moles. It is controlled by
 * the keyboard.
 * 
 * @author Shondel Archer 
 * @version 1.0
 */
public class Hammer extends Actors
{
    private int timer=103;
    private ArrayList hitAndMiss= new ArrayList();
    private String hit = "hit", miss = "miss";
    protected int numHits2, numMiss2;
    protected double hitAccuracy2;
    public static final float FONT_SIZE = 20.0f;
    public static final int WIDTH = 400;
    public static final int HEIGHT = 300;

    public Hammer()
    {

    }
    
    /**
     * Act - do whatever the Hammer wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        checkKeys();
        checkTimer();
    }
        
    /**
     * Makes the keyboard respond.
     */
    public void checkKeys()
    {
        if(Greenfoot.isKeyDown("q"))
        {
            setLocation(0,0);
            checkForMole();
        }

        if(Greenfoot.isKeyDown("w"))
        {
            setLocation(1,0);
            checkForMole();
        }

        if(Greenfoot.isKeyDown("e"))
        {
            setLocation(2,0);
            checkForMole();
        }
            
        if(Greenfoot.isKeyDown("a"))
        {
            setLocation(0,1);
            checkForMole();
        }
            
        if(Greenfoot.isKeyDown("s"))
        {
            setLocation(1,1);
            checkForMole();
        }
            
        if(Greenfoot.isKeyDown("d"))
        {
            setLocation(2,1);
            checkForMole();
        }
            
        if(Greenfoot.isKeyDown("z"))
        {
            setLocation(0,2);
            checkForMole();
        }
            
        if(Greenfoot.isKeyDown("x"))
        {
            setLocation(1,2);
            checkForMole();
        }
            
        if(Greenfoot.isKeyDown("c"))
        {
            setLocation(2,2);
            checkForMole();
     
        }
     }
    
    /**
     * Checks to see if a mole is present where the hammer is.
     * If it is then it is a hit.
     */
    public void checkForMole()
    {
        if(this.getOneIntersectingObject(RandomMole.class) != null)
        {
            playHit();
        }
        
        else
        {
            playMiss();
        }
    }

    /**
     * Plays a sound when hitting the mole.
     * Adds 5 points to the score.
     * Adds a hit slot to the ArrayList.
     */
    public void playHit()
    {
        Greenfoot.playSound("boing.wav");
        setImage("Hammer1.png");
        hitAndMiss.add(hit);

    }
    
    /**
     * Plays a sound when missing the mole.
     * Subtracts 10 points from the score.
     * Adds a miss slot to the ArrayList.
     */
    public void playMiss()
    {
        Greenfoot.playSound("homer.wav");
        setImage("Hammer0.png");
        hitAndMiss.add(miss);
    }
    
    /**
     * Checks to see if time has run out.
     * If so, the game is stopped.
     */
    public void checkTimer() 
    {
        if (timer == 0) 
        {
            gameOver();
        }
             
        else
        {
            timer--;
        }
    }
    

    /**
     * Stops the game and prints the number of moles hit,
     * missed, and accuracy using an array.
     */
    public void gameOver() 
    {
        int numHits = 0;
        int numMiss = 0;
        
        Greenfoot.stop();
        
        for(int i = 0; i < hitAndMiss.size(); i++)
        {
            if(hitAndMiss.get(i).equals(hit))
            {
                numHits++;
            }
            
            else
            {
                numMiss++;
            }
        }
        
        double hitAccuracy = numHits/(double)(numHits + numMiss);
        
        getWorld().removeObjects(getWorld().getObjects(RandomMole.class));
        
        makeImage("Game Over!", "Your Score: " + (numHits*5 - numMiss*5), "Moles Hit: " + numHits, "Moles Missed: " + numMiss, "Accuracy: " + hitAccuracy*100 + "%");
        
    }
    
    /**
     * Make the message image.
     */
    public void makeImage(String title, String prefix1, String prefix2, String prefix3, String prefix4)
    {
        GreenfootImage image = new GreenfootImage(WIDTH, HEIGHT);

        image.setColor(new Color(255,255,255, 128));
        image.fillRect(0, 0, WIDTH, HEIGHT);
        image.setColor(new Color(0, 0, 0, 128));
        image.fillRect(5, 5, WIDTH-10, HEIGHT-10);
        Font font = image.getFont();
        font = font.deriveFont(FONT_SIZE);
        image.setFont(font);
        image.setColor(Color.WHITE);
        image.drawString(title, 125, 50);
        image.drawString(prefix1, 55, 100);
        image.drawString(prefix2, 55, 150);
        image.drawString(prefix3, 55, 200);
        image.drawString(prefix4, 55, 250);
        
        setImage(image);
        setLocation(getWorld().getWidth()/2, getWorld().getHeight()/2);
    }
    

}
